@@ -1,5 +1,5 @@
 package Net::Hadoop::Oozie;
-$Net::Hadoop::Oozie::VERSION = '0.103';
+$Net::Hadoop::Oozie::VERSION = '0.104';
 use 5.010;
 use strict;
 use warnings;
@@ -505,11 +505,12 @@ sub active_job_paths {
 #
 sub coordinators_with_the_same_appname_on_the_same_path {
     my $self  = shift;
-    my $path  = $self->active_job_paths('coordinator');
+    my $apath = $self->active_job_paths('coordinator');
+
     my $multi = {
-        map  { $_ => $path->{$_} }
-        grep { @{ $path->{$_} } > 1 }
-        keys %{ $path }
+        map  { $_ => $apath->{$_} }
+        grep { @{ $apath->{$_} } > 1 }
+        keys %{ $apath }
     };
 
     my $dupe = {};
@@ -527,6 +528,30 @@ sub coordinators_with_the_same_appname_on_the_same_path {
            keys %{ $dupe };
 }
 
+sub coordinators_on_the_same_path {
+    my $self  = shift;
+    my $apath = $self->active_job_paths('coordinator');
+
+    my $multi = {
+        map  { $_ => $apath->{$_} }
+        grep { @{ $apath->{$_} } > 1 }
+        keys %{ $apath }
+    };
+
+    my %rv;
+    for my $path ( keys %{ $multi } ) {
+        for my $coord ( @{ $multi->{ $path } }) {
+            foreach my $cid ( keys %{ $coord } ) {
+                my $meta = $coord->{ $cid };
+                # filter status=RUNNING?
+                $rv{ $path }{ $cid } = $meta->{ coordJobName };
+            }
+        }
+    }
+
+    return %rv;
+}
+
 # param 1 : fractional hours
 # param 2 : pattern for appname filtering
 
@@ -872,7 +897,7 @@ Net::Hadoop::Oozie
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -990,7 +1015,7 @@ applied from the end of the list.
 =head3 submit_job
 
 For details about job submission through REST, see
-L<https://oozie.apache.org/docs/4.0.0/WebServicesAPI.html#Job_Submission>.
+L<https://oozie.apache.org/docs/4.2.0/WebServicesAPI.html#Job_Submission>.
 
 Required parameters are listed below.
 
@@ -1077,6 +1102,8 @@ please) to check when it's done (untested code :-).
 
 =head3 active_job_paths
 
+=head3 coordinators_on_the_same_path
+
 =head3 coordinators_with_the_same_appname_on_the_same_path
 
 Returns a hash consisting of duplicated application names for multiple coordinators.
